summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/gui/application/main.cpp4
-rw-r--r--src/gui/kdeext/klearlook.cpp4
2 files changed, 4 insertions, 4 deletions
diff --git a/src/gui/application/main.cpp b/src/gui/application/main.cpp
index 8d771d2..ff03584 100644
--- a/src/gui/application/main.cpp
+++ b/src/gui/application/main.cpp
@@ -378,7 +378,7 @@ void testInstalledVersion()
" successfully.\n\n"
" 2. The upgrade was installed in a non-standard directory,\n"
" and an old version was found in a standard directory. If so,\n"
- " you will need to add the correct directory to your KDEDIRS\n"
+ " you will need to add the correct directory to your TDEDIRS\n"
" environment variable before you can run it.").tqarg(VERSION).tqarg(installedVersion),
i18n("Installation problem"));
@@ -394,7 +394,7 @@ void testInstalledVersion()
" it yourself, check that you have run \"make install\" and that\n"
" the procedure completed successfully.\n\n"
" 2. Rosegarden has been installed in a non-standard directory,\n"
- " and you need to add this directory to your KDEDIRS environment\n"
+ " and you need to add this directory to your TDEDIRS environment\n"
" variable before you can run it. This may be the case if you\n"
" installed into $HOME or a local third-party package directory\n"
" like /usr/local or /opt."),
diff --git a/src/gui/kdeext/klearlook.cpp b/src/gui/kdeext/klearlook.cpp
index 3a4af04..0a2a1d2 100644
--- a/src/gui/kdeext/klearlook.cpp
+++ b/src/gui/kdeext/klearlook.cpp
@@ -103,7 +103,7 @@ static const int arrowHMargin = 6;
static const int rightBorder = 12;
#if TDE_VERSION >= 0x30200
// Try to read $KDEHOME/share/config/kickerrc to find out if kicker is transparent...
static TQString readEnvPath( const char *env ) {
TQCString path = getenv( env );
@@ -114,7 +114,7 @@ static TQString readEnvPath( const char *env ) {
}
static bool kickerIsTrans() {
- TQString kdeHome( readEnvPath( getuid() ? "KDEHOME" : "KDEROOTHOME" ) ),
+ TQString kdeHome( readEnvPath( getuid() ? "TDEHOME" : "KDEROOTHOME" ) ),
cfgFileName;
bool trans = false;
@@ -103,7 +103,7 @@ static const int arrowHMargin = 6;
static const int rightBorder = 12;
#if TDE_VERSION >= 0x30200
-// Try to read $KDEHOME/share/config/kickerrc to find out if kicker is transparent...
+// Try to read $TDEHOME/share/config/kickerrc to find out if kicker is transparent...
static TQString readEnvPath( const char *env ) {
TQCString path = getenv( env );